'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require('react'));

var _propTypes = _interopRequireDefault(require('prop-types'));

var _clsx = _interopRequireDefault(require('clsx'));

var _core = require('@material-ui/core');

var _arrow = require('../../assets/images/arrow.svg');

var _PositionedLink = _interopRequireDefault(require('../PositionedLink'));

var _LinkWrapper = require('../LinkWrapper/LinkWrapper');

var _excluded = ['title', 'route', 'index', 'icon', 'position', 'padding', 'isArrow', 'setActiveLink'];

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
}

function _extends() {
    _extends =
        Object.assign ||
        function (target) {
            for (var i = 1; i < arguments.length; i++) {
                var source = arguments[i];
                for (var key in source) {
                    if (Object.prototype.hasOwnProperty.call(source, key)) {
                        target[key] = source[key];
                    }
                }
            }
            return target;
        };
    return _extends.apply(this, arguments);
}

function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    return target;
}

function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
        obj[key] = value;
    }
    return obj;
}

var useStyles = (0, _core.makeStyles)(function (_ref) {
    var breakpoints = _ref.breakpoints,
        spacing = _ref.spacing;
    return {
        arrowLinkContainer: _defineProperty({}, breakpoints.up('sm'), {
            width: '50%'
        }),
        linkArrowRoot: function linkArrowRoot(_ref2) {
            var _ref3;

            var isLinkActive = _ref2.isLinkActive,
                fontSize = _ref2.fontSize,
                colorOnHover = _ref2.colorOnHover;
            return (
                (_ref3 = {
                    color: isLinkActive && colorOnHover
                }),
                _defineProperty(_ref3, breakpoints.only('sm'), {
                    fontSize: fontSize * 0.7
                }),
                _defineProperty(_ref3, breakpoints.only('md'), {
                    fontSize: fontSize * 0.8
                }),
                _defineProperty(_ref3, breakpoints.only('xs'), {
                    fontSize: fontSize * 0.5,
                    color: colorOnHover
                }),
                _ref3
            );
        },
        svg: function svg(_ref4) {
            var isLinkActive = _ref4.isLinkActive,
                colorOnHover = _ref4.colorOnHover;
            return _defineProperty(
                {
                    fill: isLinkActive && colorOnHover
                },
                breakpoints.only('xs'),
                {
                    fill: colorOnHover,
                    transform: 'rotateZ(90deg) translateX(3px)',
                    transition: 'all 0.2s linear'
                }
            );
        },
        mobileArrow: function mobileArrow(_ref6) {
            var size = _ref6.size,
                isLinkActive = _ref6.isLinkActive;
            return {
                width: size * 0.5,
                height: size * 0.5,
                marginLeft: spacing(2),
                transform: isLinkActive && 'rotateZ(-90deg) translateX(4px)',
                transition: 'all 0.2s linear'
            };
        }
    };
});

var LinkArrow = function LinkArrow(_ref7) {
    var title = _ref7.title,
        route = _ref7.route,
        index = _ref7.index,
        icon = _ref7.icon,
        position = _ref7.position,
        padding = _ref7.padding,
        isArrow = _ref7.isArrow,
        setActiveLink = _ref7.setActiveLink,
        props = _objectWithoutProperties(_ref7, _excluded);

    var classes = useStyles(props);
    var isLinkActive = props.isLinkActive,
        size = props.size;
    var isMobileView = (0, _core.useMediaQuery)(function (theme) {
        return theme.breakpoints.only('xs');
    });

    var handleLinkClick = function handleLinkClick(e) {
        if (isMobileView && isArrow) {
            e.preventDefault();
            setActiveLink(isLinkActive ? null : index);
        }
    };

    var handleLinkOnMouseEnter = function handleLinkOnMouseEnter() {
        !isMobileView && setActiveLink(index);
    };

    return (
        (isMobileView || (!isMobileView && isArrow)) &&
        /*#__PURE__*/ _react.default.createElement(
            _core.Box,
            {
                className: classes.arrowLinkContainer
            },
            /*#__PURE__*/ _react.default.createElement(
                _PositionedLink.default,
                _extends(
                    {
                        className: classes.linkArrowRoot,
                        href: route,
                        onClick: handleLinkClick,
                        onMouseEnter: handleLinkOnMouseEnter,
                        icon: icon,
                        position: position,
                        padding: padding
                    },
                    props
                ),
                title,
                ((isLinkActive && !isMobileView) || (isMobileView && isArrow)) &&
                    /*#__PURE__*/ _react.default.createElement(_arrow.ReactComponent, {
                        width: size,
                        className: (0, _clsx.default)(classes.svg, isArrow && isMobileView && classes.mobileArrow)
                    })
            )
        )
    );
};

LinkArrow.propTypes = {
    title: _propTypes.default.string.isRequired,
    route: _propTypes.default.string,
    isArrow: _propTypes.default.bool,
    index: _propTypes.default.number.isRequired,
    icon: _propTypes.default.string,
    setActiveLink: _propTypes.default.func.isRequired,
    isLinkActive: _propTypes.default.bool.isRequired,
    position: _propTypes.default.string,
    padding: _propTypes.default.number,
    size: _propTypes.default.number,
    common: _LinkWrapper.commonTypes
};
LinkArrow.defaultProps = {
    position: 'right',
    size: 20,
    padding: 20,
    common: {
        color: '#868686',
        colorOnHover: '#FFFFFF',
        fontSize: 40,
        fontWeight: 400
    }
};
var _default = LinkArrow;
exports.default = _default;
